// Class: ColMajorEnvIterator
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;
import java.util.Iterator;

/**
 *  Environment-Based Applications:<br>
 *
 *    A ColMajorEnvIterator object provides an iterator that
 *    steps through the locations of a BoundedEnv object in
 *    column-major order.  It iterates through the locations and
 *    processes the columns of the environment, from 0 to C - 1,
 *    where C is the number of columns in the environment.  As
 *    part of processing each column, it traverses through the
 *    rows of that column, from 0 to R - 1, where R is the
 *    number of rows in the environment.
 *
 *  @author Alyce Brady
 *  @version 1 September 2002
 *  @see Environment
 *  @see Location
 **/
public class ColMajorEnvIterator extends EnvIterator
{
    /** Constructs an iterator object that steps through an
     *  environment.
     *  @param environment     environment to iterate through
     **/
    public ColMajorEnvIterator(BoundedEnv environment)
    {
        super(environment);
    }

    /** Helper Method: Finds next location for iterator.
     *  (Algorithm not implemented yet -- does not advance iterator.)
     **/
    protected Location findNextLocation()
    {
        // For now, just return the current "next" location without
        // advancing the iterator.
        System.out.println("The iterator for column-major traversals " +
                           "has not been implemented yet.");
        return nextLocation();
    }

}
