// Class: IteratorLab
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

/**
 *  Environment-Based Applications:<br>
 *
 *    The IteratorLab class provides a main method that creates an
 *    animation of 2-D structure traversals using iterators.
 *
 *  @author Alyce Brady
 *  @version 1 September 2002
 **/

public class IteratorLab
{
    // Specify dimensions of graphics display for environment.
    private static final int DISPLAY_WIDTH = 400;
    private static final int DISPLAY_HEIGHT = 400;

    // Specify number of rows and columns in environment.
    private static final int ENV_ROWS = 5;
    private static final int ENV_COLS = 5;

    // Specify the environment's background color and highlight color.
    private static final Color BACKGROUND_COLOR = new Color(0, 155, 255);
    private static final Color HIGHLIGHT_COLOR = Color.red;

    /**
     *  Start the 2-D Traversal Algorithms program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        System.out.println ("Welcome to the 2-D Iterator Program.");

        // Construct a bounded environment in which to run
        // various 2-D traversal algorithms.  Specify the
        // dimensions and background color of the environment.
        BoundedEnv env = new BoundedEnv(ENV_ROWS, ENV_COLS);

        // Specify how to display objects in the environment
        // (which are color blocks in this program).
        DisplayMap.associate("ColorBlock", new ColorBlockDisplay());

        // Construct a list of the iterators to use in various traversals.
        TraversalGUI.register("Row-Major Order", RowMajorEnvIterator.class);
        TraversalGUI.register("Col-Major Order", ColMajorEnvIterator.class);

        // Construct a graphical user interface (GUI).  The GUI
        // provides buttons to run the traversal algorithms and
        // displays an animation of each traversal as it runs
        // by highlighting cells in the environment.
        TraversalGUI gui = new TraversalGUI(env, BACKGROUND_COLOR,
                                            HIGHLIGHT_COLOR,
                                            DISPLAY_WIDTH, DISPLAY_HEIGHT);
        gui.setVisible(true);

        System.out.println ("Close GUI display window to quit.");
    }

}
